==> pano_rtc-0.9.3-dev.1.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/RtcVideoStreamEngine.kt <==
package video.pano.pano_rtc

import com.pano.rtc.api.RtcSnapshotVideoOption
import com.pano.rtc.api.RtcVideoStreamManager
import video.pano.pano_rtc.api.IRtcVideoStreamManager
import video.pano.pano_rtc.events.RtcVideoStreamEvent
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getImageFileFormat
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getVideoProfileType

class RtcVideoStreamEngine(private val manager: RtcVideoStreamManager?) : FlutterWrapper(),
        IRtcVideoStreamManager {

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/api_video_streamMgr")
        eventChannel = PanoRtcPlugin.createEventChannel("pano_rtc/events_video_streamMgr")
        methodChannel.setMethodCallHandler(this)
        eventChannel?.setStreamHandler(this)
        manager?.setCallback(RtcVideoStreamEvent { methodName, data ->
            emit(methodName, data)
        })
    }

    override fun createVideoStream(params: Map<String, *>, callback: Callback) {
        val deviceId = params["deviceId"] as String
        callback.success(manager?.createVideoStream(deviceId))
    }

    override fun destroyVideoStream(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        callback.success(manager?.destroyVideoStream(streamId))
    }

    override fun setCaptureDevice(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        val deviceId = params["deviceId"] as String
        callback.success(manager?.setCaptureDevice(streamId, deviceId))
    }

    override fun getCaptureDevice(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        callback.success(manager?.getCaptureDevice(streamId))
    }

    override fun startVideo(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        val configMap = params["config"] as Map<*, *>
        val profileType = configMap["profileType"] as Int
        callback.success(manager?.startVideo(streamId, getVideoProfileType(profileType)))
    }

    override fun stopVideo(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        callback.success(manager?.stopVideo(streamId))
    }

    override fun muteVideo(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        callback.success(manager?.muteVideo(streamId))
    }

    override fun unmuteVideo(params: Map<String, *>, callback: Callback) {
        val streamId = params["streamId"] as Int
        callback.success(manager?.unmuteVideo(streamId))
    }

    override fun subscribeVideo(params: Map<String, *>, callback: Callback) {
        val userId = params["userId"] as Long
        val streamId = params["streamId"] as Int
        val configMap = params["config"] as Map<*, *>
        val profileType = configMap["profileType"] as Int
        callback.success(manager?.subscribeVideo(userId, streamId, getVideoProfileType(profileType)))
    }

    override fun unsubscribeVideo(params: Map<String, *>, callback: Callback) {
        val userId = params["userId"] as Long
        val streamId = params["streamId"] as Int
        callback.success(manager?.unsubscribeVideo(userId, streamId))
    }

    override fun snapshotVideo(params: Map<String, *>, callback: Callback) {
        val userId = params["userId"] as Long
        val streamId = params["streamId"] as Int
        val outputDir = params["outputDir"] as String
        val optionMap = params["option"] as Map<*, *>
        val option = RtcSnapshotVideoOption().apply {
            this.mirror = optionMap["mirror"] as Boolean
            this.format = getImageFileFormat(optionMap["format"] as Int)
        }
        callback.success(manager?.snapshotVideo(userId, streamId, outputDir, option))
    }


}

==> pano_rtc-0.9.4-dev.5.tar.gz: android/src/main/kotlin/video/pano/pano_rtc/RtcVideoStreamEngine.kt <==
package video.pano.pano_rtc

import com.pano.rtc.api.RtcSnapshotVideoOption
import com.pano.rtc.api.RtcVideoStreamManager
import com.pano.rtc.api.RtcView
import video.pano.pano_rtc.api.IRtcVideoStreamManager
import video.pano.pano_rtc.events.RtcVideoStreamEvent
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getImageFileFormat
import video.pano.pano_rtc.utils.EnumValueConvert.StaticParams.getVideoProfileType

class RtcVideoStreamEngine(private val manager: RtcVideoStreamManager?) : FlutterWrapper(),
        IRtcVideoStreamManager {

    init {
        methodChannel = PanoRtcPlugin.createMethodChannel("pano_rtc/api_video_streamMgr")
        eventChannel = PanoRtcPlugin.createEventChannel("pano_rtc/events_video_streamMgr")
        methodChannel.setMethodCallHandler(this)
        eventChannel?.setStreamHandler(this)
        manager?.setCallback(RtcVideoStreamEvent { methodName, data ->
            emit(methodName, data)
        })
    }

    override fun createVideoStream(params: Map<String, *>, callback: Callback) {
        val deviceId = params["deviceId"] as String
        callback.success(manager?.createVideoStream(deviceId))
    }

    override fun destroyVideoStream(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.destroyVideoStream(streamId))
    }

    override fun setCaptureDevice(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        val deviceId = params["deviceId"] as String
        callback.success(manager?.setCaptureDevice(streamId, deviceId))
    }

    override fun getCaptureDevice(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.getCaptureDevice(streamId))
    }

    override fun startVideo(params: Map<String, *>, callback: Callback) {
        val view = params["view"] as RtcView
        val streamId = (params["streamId"] as Number).toInt()
        val configMap = params["config"] as Map<*, *>
        val profileType = (configMap["profileType"] as Number).toInt()
        view.mirror = configMap["mirror"] as Boolean
        manager?.setLocalVideoRender(streamId, view)
        callback.success(manager?.startVideo(streamId, getVideoProfileType(profileType)))
    }

    override fun stopVideo(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.stopVideo(streamId))
    }

    override fun muteVideo(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.muteVideo(streamId))
    }

    override fun unmuteVideo(params: Map<String, *>, callback: Callback) {
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.unmuteVideo(streamId))
    }

    override fun subscribeVideo(params: Map<String, *>, callback: Callback) {
        val view = params["view"] as RtcView
        val userId = (params["userId"] as Number).toLong()
        val streamId = (params["streamId"] as Number).toInt()
        val configMap = params["config"] as Map<*, *>
        val profileType = (configMap["profileType"] as Number).toInt()
        view.mirror = configMap["mirror"] as Boolean
        manager?.setRemoteVideoRender(userId, streamId, view)
        callback.success(manager?.subscribeVideo(userId, streamId, getVideoProfileType(profileType)))
    }

    override fun unsubscribeVideo(params: Map<String, *>, callback: Callback) {
        val userId = (params["userId"] as Number).toLong()
        val streamId = (params["streamId"] as Number).toInt()
        callback.success(manager?.unsubscribeVideo(userId, streamId))
    }

    override fun snapshotVideo(params: Map<String, *>, callback: Callback) {
        val userId = (params["userId"] as Number).toLong()
        val streamId = (params["streamId"] as Number).toInt()
        val outputDir = params["outputDir"] as String
        val optionMap = params["option"] as Map<*, *>
        val option = RtcSnapshotVideoOption().apply {
            this.mirror = optionMap["mirror"] as Boolean
            this.format = getImageFileFormat((optionMap["format"] as Number).toInt())
        }
        callback.success(manager?.snapshotVideo(userId, streamId, outputDir, option))
    }


}
